@@ -1,5 +1,6 @@
+use rustc_hash::FxHashSet;
 use swc_atoms::JsWord;
-use swc_common::collections::{AHashMap, AHashSet};
+use swc_common::collections::AHashMap;
 use swc_ecma_ast::*;
 use swc_ecma_utils::{ident::IdentLike, Id};
 use swc_ecma_visit::{noop_visit_type, Visit, VisitWith};
@@ -21,7 +22,7 @@ impl Analyzer {
     pub(super) fn into_rename_map(
         mut self,
         freq: &CharFreqInfo,
-        preserved: &AHashSet<Id>,
+        preserved: &FxHashSet<Id>,
     ) -> AHashMap<Id, JsWord> {
         let mut map = RenameMap::default();
 
